`timescale 1ns / 1ps

//// Author:         oaks @cyberchabudai.org
//// Module Name:    matrix_led_ctrl
//// Revision:       1.0
//// Tool versions:  QuatusII 11.1
//// Target Devices: EP4CE22F17C6N (DE0-nano)
//// Description:    matrix_led_ctrl top module

module matrix_led_ctrl (
	clk, rst_n, 
	avs_s1_ram_adr, avs_s1_ram_wdata, avs_s1_ram_rdata, avs_s1_ram_we, 
	led_srck, led_srclr_n, led_srdout, led_col_dout
	);

	//// input and output ////
	input				clk;
	input				rst_n;

	input	[3:0]		avs_s1_ram_adr;
	input	[31:0]		avs_s1_ram_wdata;
	output	[31:0]		avs_s1_ram_rdata;
	input				avs_s1_ram_we;

	output				led_srck;
	output				led_srclr_n;
	output				led_srdout;
	output	[15:0]		led_col_dout;


	wire	[3:0]		ram_adr_a;
	wire	[31:0]		ram_wdata_a;
	wire	[31:0]		ram_rdata_a;
	wire				ram_we_a;

	wire	[3:0]		ram_adr_b;
	wire	[31:0]		ram_rdata_b;


	assign ram_adr_a = avs_s1_ram_adr;
	assign ram_wdata_a = avs_s1_ram_wdata;
	assign ram_we_a = avs_s1_ram_we;

	assign avs_s1_ram_rdata = ram_rdata_a;


	matrix_led_ctrl_core matrix_led_ctrl_core (
		.clk(clk), .rst_n(rst_n),
		.ram_radr(ram_adr_b), .ram_rdata(ram_rdata_b),
		.led_srck(led_srck), .led_srclr_n(led_srclr_n), 
		.led_srdout(led_srdout), .led_col_dout(led_col_dout)
	);

	ram_mlc ram (
		.clock(clk), 
		.address_a(ram_adr_a), .address_b(ram_adr_b),
		.data_a(ram_wdata_a), .data_b(32'd0),
		.wren_a(ram_we_a), .wren_b(1'b0),
		.q_a(ram_rdata_a), .q_b(ram_rdata_b)
	);


endmodule
